<?php

/**

 * Registering meta boxes

 *

 * In this file, I'll show you how to extend the class to add more field type (in this case, the 'taxonomy' type)

 * All the definitions of meta boxes are listed below with comments, please read them carefully.

 * Note that each validation method of the Validation Class MUST return value instead of boolean as before

 *

 * You also should read the changelog to know what has been changed

 *

 * For more information, please visit: http://www.deluxeblogtips.com/2010/04/how-to-create-meta-box-wordpress-post.html

 *

 */



/********************* BEGIN EXTENDING CLASS ***********************/



/**

 * Extend RW_Meta_Box class

 * Add field type: 'taxonomy'

 */

class RW_Meta_Box_Taxonomy extends RW_Meta_Box {

	

	function add_missed_values() {

		parent::add_missed_values();

		

		// add 'multiple' option to taxonomy field with checkbox_list type

		foreach ($this->_meta_box['fields'] as $key => $field) {

			if ('taxonomy' == $field['type'] && 'checkbox_list' == $field['options']['type']) {

				$this->_meta_box['fields'][$key]['multiple'] = true;

			}

		}

	}

	

	// show taxonomy list

	function show_field_taxonomy($field, $meta) {

		global $post;

		

		if (!is_array($meta)) $meta = (array) $meta;

		

		$this->show_field_begin($field, $meta);

		

		$options = $field['options'];

		$terms = get_terms($options['taxonomy'], $options['args']);

		

		// checkbox_list

		if ('checkbox_list' == $options['type']) {

			foreach ($terms as $term) {

				echo "<input type='checkbox' name='{$field['id']}[]' value='$term->slug'" . checked(in_array($term->slug, $meta), true, false) . " /> $term->name<br/>";

			}

		}

		// select

		else {

			echo "<select name='{$field['id']}" . ($field['multiple'] ? "[]' multiple='multiple' style='height:auto'" : "'") . ">";

		

			foreach ($terms as $term) {

				echo "<option value='$term->slug'" . selected(in_array($term->slug, $meta), true, false) . ">$term->name</option>";

			}

			echo "</select>";

		}

		

		$this->show_field_end($field, $meta);

	}

}



/********************* END EXTENDING CLASS ***********************/



/********************* BEGIN DEFINITION OF META BOXES ***********************/



// prefix of meta keys, optional

// use underscore (_) at the beginning to make keys hidden, for example $prefix = '_rw_';

// you also can make prefix empty to disable it

$prefix = 'cg_';



$meta_boxes = array();




$meta_boxes[] = array(
	'id' => 'white_paper',
	'title' => 'Type',
	'pages' => array('whitepapers'),
	'fields' => array(
		array(
			'name' => 'White Paper Type',					// field name
			'desc' => 'Select the white paper type',	// field description, optional
			'id' => 'whitepaper_type',				// field id, i.e. the meta key
			'type' => 'radio',						// radio box
			'options' => array(						// array of key => value pairs for radio options
				'y' => 'White Paper',
				'n' => 'Case Study'
			),
			'std' => 'y',					// default value, optional
		),
	)
);


$meta_boxes[] = array(
	'id' => 'client_name',
	'title' => 'Client Name',
	'pages' => array('testimonials'),
	'fields' => array(
		array(
			'name' => 'Client Name',					// field name
			'desc' => 'Please insert Client name which will display in Testimonials box.',	// field description, optional
			'id' => 'testi_client',				// field id, i.e. the meta key
			'type' => 'text',				// radio box
								// default value, optional
		),
	)
);

$meta_boxes[] = array(
	'id' => 'client_phone',
	'title' => 'Client Phone Number',
	'pages' => array('testimonials'),
	'fields' => array(
		array(
			'name' => 'Client Phone',					// field name
			'desc' => 'Please insert Client Phone number which will display in Testimonials box.',	// field description, optional
			'id' => 'testi_phone',				// field id, i.e. the meta key
			'type' => 'text',				// radio box
								// default value, optional
		),
	)
);



foreach ($meta_boxes as $meta_box) {

	$my_box = new RW_Meta_Box_Taxonomy($meta_box);

}



/********************* END DEFINITION OF META BOXES ***********************/



/********************* BEGIN VALIDATION ***********************/



/**

 * Validation class

 * Define ALL validation methods inside this class

 * Use the names of these methods in the definition of meta boxes (key 'validate_func' of each field)

 */

class RW_Meta_Box_Validate {

	function check_name($text) {

		if ($text == 'Anh Tran') {

			return 'He is Rilwis';

		}

		return $text;

	}

}
?>